IUnknown

Struct IUnknown 

pub struct IUnknown(/* private fields */);
Base interface for all COM interfaces.

All COM interfaces (and thus WinRT classes and interfaces) implement IUnknown under the hood to provide reference-counted lifetime management as well as the ability to query for additional interfaces that the object may implement.